Construct a quantile basis
Usage
qfmix_basis(
type = c("polynomial", "legendre", "pareto", "gev", "empirical"),
p = 4L,
controls = NULL
)Arguments
- type
One of
"polynomial","legendre","pareto","gev","empirical".- p
Number of basis functions (sieve dimension). Ignored for
"empirical"(set by the controls).- controls
For
"empirical": a list of numeric vectors (or a matrix with one column per control unit) of control observations whose empirical quantile functions form the basis.